summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetepassword.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetepassword.cpp')
-rw-r--r--kopete/libkopete/kopetepassword.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kopete/libkopete/kopetepassword.cpp b/kopete/libkopete/kopetepassword.cpp
index 875e2edf..5fd729a7 100644
--- a/kopete/libkopete/kopetepassword.cpp
+++ b/kopete/libkopete/kopetepassword.cpp
@@ -57,7 +57,7 @@ public:
}
/** Reference count */
int refCount;
/** Group to use for TDEConfig and KWallet */
const TQString configGroup;
/** Is the password being remembered? */
bool remembered;
@@ -92,10 +92,10 @@ public:
void begin()
{
kdDebug( 14010 ) << k_funcinfo << endl;
- Kopete::WalletManager::self()->openWallet( this, TQT_SLOT( walletReceived( KWallet::Wallet* ) ) );
+ Kopete::WalletManager::self()->openWallet( this, TQT_SLOT( walletReceived( TDEWallet::Wallet* ) ) );
}
- void walletReceived( KWallet::Wallet *wallet )
+ void walletReceived( TDEWallet::Wallet *wallet )
{
kdDebug( 14010 ) << k_funcinfo << endl;
mWallet = wallet;
@@ -112,7 +112,7 @@ public:
protected:
Kopete::Password mPassword;
- KWallet::Wallet *mWallet;
+ TDEWallet::Wallet *mWallet;
};
/**
@@ -131,7 +131,7 @@ public:
TQString grabPassword()
{
// Before trying to read from the wallet, check if the config file holds a password.
// If so, remove it from the config and set it through KWallet instead.
TQString pwd;
if ( mPassword.d->remembered && !mPassword.d->passwordFromTDEConfig.isNull() )
{
@@ -281,7 +281,7 @@ public:
return true;
}
- if ( KWallet::Wallet::isEnabled() )
+ if ( TDEWallet::Wallet::isEnabled() )
{
// If we end up here, the wallet is enabled, but failed somehow.
// Ask the user what to do now.
@@ -294,7 +294,7 @@ public:
"do you want to save the password in the <b>unsafe</b> configuration file instead?</qt>" ),
i18n( "Unable to Store Secure Password" ),
KGuiItem( i18n( "Store &Unsafe" ), TQString::fromLatin1( "unlock" ) ),
- TQString::fromLatin1( "KWalletFallbackToTDEConfig" ) ) != KMessageBox::Continue )
+ TQString::fromLatin1( "TDEWalletFallbackToTDEConfig" ) ) != KMessageBox::Continue )
{
return false;
}
@@ -57,7 +57,7 @@ public:
/** Reference count */
int refCount;
- /** Group to use for TDEConfig and KWallet */
+ /** Group to use for TDEConfig and TDEWallet */
const TQString configGroup;
/** Is the password being remembered? */
@@ -131,7 +131,7 @@ public:
{
// Before trying to read from the wallet, check if the config file holds a password.
- // If so, remove it from the config and set it through KWallet instead.
+ // If so, remove it from the config and set it through TDEWallet instead.
TQString pwd;
if ( mPassword.d->remembered && !mPassword.d->passwordFromTDEConfig.isNull() )